#
# spec file for package 4pane
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
# Copyright (c) 2016 Packman Team <packman@links2linux.de>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#

Name:           4pane
Version:        4.0
Release:        7.1
Summary:        A multi-pane detailed-list file manager
License:        GPL-3.0
Group:          Productivity/File utilities
Url:            http://www.4pane.co.uk/
Source0:        https://sourceforge.net/projects/fourpane/files/%{version}/%{name}-%{version}.tar.gz
%if 0%{?is_opensuse}
BuildRequires:  wxWidgets-devel >= 3
%else
# SLE_12 lacks wxWidgets_3.0-devel
BuildRequires:  wxWidgets-devel < 3
%define _use_internal_dependency_generator 0
%define __find_requires %wx_requires
%endif
BuildRequires:  ImageMagick
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  xz-devel
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
4Pane is a multi-pane detailed-list file manager.
It favors speed over visual effects.
In addition to standard file manager features, it offers multiple undo and redo
of most operations (including deletions), archive management including "virtual
browsing" inside archives, multiple renaming/duplication of files, a terminal
emulator and user-defined tools.

%prep
%setup -q
sed -i -e "s|\$(datadir)/doc|%{_docdir}|g" Makefile.in
sed -i -e "s|/usr/doc/4Pane/|%{_docdir}/4Pane/|g" Configure.cpp

%build
%configure
make %{?_smp_mflags}


%install
make %{?_smp_mflags} DESTDIR=%{buildroot} install
%find_lang 4Pane
mkdir -vp %{buildroot}/%{_datadir}/applications
mkdir -vp %{buildroot}/%{_datadir}/appdata
cd %{buildroot}/%{_datadir}/applications
ln -s ../4Pane/rc/4Pane.desktop 4Pane.desktop
pushd %{buildroot}%{_datadir}/icons/hicolor/48x48/apps
convert -resize 48x48! 4Pane.png 4Pane.png
popd
%fdupes -s %{buildroot}/%{_datadir}

%files -f 4Pane.lang
%defattr(-,root,root,-)
%doc LICENCE
%{_bindir}/%{name}
%{_bindir}/4Pane
%dir %{_datadir}/4Pane
%dir %{_datadir}/4Pane/bitmaps
%{_datadir}/4Pane/bitmaps/*
%{_datadir}/appdata
%{_datadir}/icons/hicolor/*
%{_datadir}/4Pane/rc
%{_datadir}/applications/4Pane.desktop
%dir %{_docdir}/4Pane
%{_docdir}/4Pane/*

%changelog
* Wed May 31 2017 aloisio@gmx.com
- Added LICENCE file
* Fri Apr 28 2017 jengelh@inai.de
- Corrected description
* Thu Apr 27 2017 aloisio@gmx.com
- Corrected summary
* Fri Feb 17 2017 olaf@aepfle.de
- Use wxWidgets-3_0
* Sun May  8 2016 aloisio@gmx.com
- Update to version 4.0:
  * Moving or pasting files now uses threads
  * This allows 4Pane to be responsive even during pastes of
    very large files, and also makes it possible to cancel such
    pastes.
  * A better method of detecting a file's system mime-type is
    now used
  * 4Pane can now be built with clang as well as with g++
  version 3.0:
  * It's now possible to use gtk3 instead of gtk2, providing the
    gtk3 version is sufficiently recent
  * 4Pane now builds and runs on GNU Hurd, though some features
    are missing: in particular FilesystemWatcher and samba support
  * There is now an optional Preview feature: hovering over an
    image or a text file will, after a delay, show the contents in
    a 'tooltip'
  * Double-clicking on a file now uses the system's mime-type
    method to decide which application to use to open the file
    Previous versions used just 4Pane's built-in method. Now by
    default both are tried in turn, the system method first,
    but this can be changed in Options > Configuring 4Pane >
    Miscellaneous > Other
  version 2.0:
  * It's now possible to mount a remote partition over ssh, using
    sshfs.
  * 4Pane now uses 'inotify' to keep it informed of changes to
    the filesystem. This means that the display updates
    to show altered dirs and files, whether they were changed by
    4Pane itself or from elsewhere. This is enabled by default.
  * Any /etc/fstab entries for network mounts (nfs, sshfs and
    samba) are now added to their 'mount' dialogs
  * There's now a separate icon for broken symlinks.
  version 1.0:
  * For the musophobic, added the ability to use the keyboard to:
    navigate to/from the panes, terminal emulator, command-line
    and toolbar textctrl; return to the last-used control;
    navigate between dir-view and file-view, and to the opposite
    twinpane; cycle through multiple open tabs;
  * User-defined command parameters can now have modifiers, better
    to specify which panes to select from.
  * When the user does Copy on a treeitem, its filepath is now
    added to the (real) clipboard too.
    If 4Pane is built against >=wxGTK-2.9 it's also added to the
    primary selection.
  * It's now possible to set a background colour to panes,
    optionally different for dirviews and fileviews.
  * Added the ability to paste only the dirs in the clipboard,
    ignoring files. This makes it easy to replicate a directory
    tree.
  * A greater range of compressed files and archives can now be
    handled.
    Assuming the relevant system libs are installed:
    Files compressed with xz, lzma, lzop and compress can now be
    decompressed and (all but the last) compressed.
    Standard 7z archives can be extracted, and tar.7z ones created
    and extracted.
    Cpio and ar archives can be extracted, as can rpm and deb
    packages.
    It's also possible to peek inside tar archives compressed with
    xz (lzma1 or 2), in addition to gzip and bzip2.
    There are now different tree icons to discriminate between
    archives, compressed archives and compressed files.
  * It's now possible to change which part of a filename is
    displayed in the 'ext' column of a fileview.
    By default an extension is still considered to start at the
    first '.', but it's now possible to change this to the last or
    the penultimate one.
  * 4Pane now will (by default) use stock icons for such things as
    Copy and Undo. Improved some non-stock icons.
  * 4Pane now acquires more information about newly-found usb
    devices, and may not have to bother the user about them.
  * There is now a built-in su/sudo front-end for executing
    commands with admin privileges. This is the default, but it's
    still possible to configure to use kdesu/gksu/etc/ instead
- Spec cleanup
* Fri Aug 17 2012 seife+obs@b1-systems.com
- fix build on 12.1+
* Sat May 28 2011 detlef@links2linux.de
- initial build for PackMan <0.0.8>
